## Description

<!-- Describe your changes in detail -->

## Type of change

<!-- Mark the relevant option with [x] -->

- [ ] Bug fix (non-breaking change that fixes an issue)
- [ ] New feature (non-breaking change that adds functionality)
- [ ] Breaking change (fix or feature that would cause existing functionality to change)
- [ ] Documentation update
- [ ] Refactoring (no functional changes)
- [ ] Test improvements

## Related issues

<!-- Link any related issues: Fixes #123, Closes #456 -->

## Checklist

- [ ] My code follows the project's code style
- [ ] I have run `uv run ruff check .` and `uv run ruff format .`
- [ ] I have run `uv run pytest` and all tests pass
- [ ] I have added tests for my changes (if applicable)
- [ ] I have updated documentation (if applicable)
- [ ] My commit messages follow [conventional commits](https://www.conventionalcommits.org/)

## Breaking changes

<!-- If this is a breaking change, describe what breaks and migration steps -->

## Screenshots (if applicable)

<!-- Add screenshots to help explain your changes -->
